/*
  Organize Folder Tree
    (C) あかつきみさき(みくちぃP)
    http://sunrisemoon.net/

  このスクリプトについて
    同階層にある同じ名前のフォルダーをひとつに統合するスクリプト.

  処理対象について
    プロジェクトパネルで何も選択していない場合は,プロジェクト全体に対して処理を行います.
    プロジェクトパネルでフォルダーを選択した場合は,そのフォルダー以下に対して処理を行います.

  処理内容について
    統合は上階層から行われ,階層ごとに統合した後,下位の階層を順に処理します.
    統合対象となった階層/名前で,空になった方のフォルダーは削除されます.

    例1:
        A->B->C
        A->B->C
        は
        A->B->C
        に統合されます.

    例2:
        A->B->C
        A->C->C
        は
        A->B->C
         ->C->C
        に統合されます.

  使用方法
    1.ファイル→スクリプト→スクリプトファイルの実行から実行.

  動作保障環境
    Adobe After Effects 2022以上

  配布元
    http://sunrisemoon.net/

  バージョン情報
    2023/08/28 Ver 1.0.1 Update
        エラー文言を英語に修正.

    2023/08/27 Ver 1.0.0 Release
*/

/// <reference path="D:\lib\aftereffects.d.ts\ae.d.ts"/>

(function () {
    FolderItem.prototype.organizeFolder = function () {
        for (var i = 1; i <= this.items.length; i++) {
            var firstFolder = this.item(i);
            if (!(firstFolder instanceof FolderItem)) {
                continue;
            }

            for (var j = i + 1; j <= this.items.length; j++) {
                var secondFolder = this.item(j);
                if (!(secondFolder instanceof FolderItem)) {
                    continue;
                }

                if (firstFolder.name != secondFolder.name) {
                    continue;
                }

                for (var k = secondFolder.items.length; k >= 1; k--) {
                    secondFolder.item(k).parentFolder = firstFolder;
                }

                secondFolder.remove();
                j = j - 1;
            }

            firstFolder.organizeFolder();
        }

        return;
    }

    var selFolders = app.project.selection;
    if (selFolders == null) {
        app.beginUndoGroup("Organize Folder Tree All");
        app.project.rootFolder.organizeFolder();
        app.endUndoGroup();
    } else {
        var selFolder = selFolders[selFolders.length - 1];
        if (!(selFolder instanceof FolderItem)) {
            alert("Select folder in project panel.", "Organize Folder Tree");
            return 0;
        }

        app.beginUndoGroup("Organize Folder Tree [" + selFolder.name + "]");
        selFolder.organizeFolder();
        app.endUndoGroup();
    }

    return 0;
}).call(this);
